@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2016.
+ * Copyright (c) Kermin Elliott Fleming 2007-2017.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -248,11 +248,13 @@ NULL, /* extload_inv_idcodes */
 NULL, /* extload_namecache */
 NULL, /* extload_namecache_max */
 NULL, /* extload_namecache_lens */
+NULL, /* extload_namecache_patched */
 NULL, /* extload_sym_block */
 NULL, /* extload_node_block */
 NULL, /* extload_xc */
 NULL, /* extload_prevsymroot */
 NULL, /* extload_prevsym */
+NULL, /* extload_npar */
 0, /* extload_i */
 0, /* extload_hlen */
 0, /* extload_vt_prev */
@@ -397,6 +399,7 @@ NULL, /* fmem_buf */
 0, /* fmem_buf_siz */
 0, /* fmem_buf_offs */
 0, /* fmem_uncompressed_siz */
+0, /* disable_auto_comphier */
 
 
 /*
@@ -1091,7 +1094,6 @@ NULL, /* ctree_main 463 */
 NULL, /* afl_treesearch_gtk2_c_1 464 */
 NULL, /* window_treesearch_gtk2_c_12 465 */
 NULL, /* tree_treesearch_gtk2_c_1 466 */
-0, /* bundle_direction_treesearch_gtk2_c_3 467 */
 NULL, /* cleanup_treesearch_gtk2_c_8 468 */
 0, /* pre_import_treesearch_gtk2_c_1 469 */
 {0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0}, /* tcache_treesearch_gtk2_c_2 470 */
@@ -1099,6 +1101,8 @@ NULL, /* cleanup_treesearch_gtk2_c_8 468 */
 0, /* dnd_tgt_on_wavearea_treesearch_gtk2_c_1 */
 NULL, /* dnd_sigview */
 NULL, /* sst_vpaned */
+0, /* fetchlow */
+0, /* fetchhigh */
 
 
 /*
@@ -1857,6 +1861,7 @@ void reload_into_new_context_2(void)
  new_globals->keep_xz_colors = GLOBALS->keep_xz_colors;
  new_globals->disable_tooltips = GLOBALS->disable_tooltips;
  new_globals->do_hier_compress = GLOBALS->do_hier_compress;
+ new_globals->disable_auto_comphier = GLOBALS->disable_auto_comphier;
  new_globals->do_initial_zoom_fit = GLOBALS->do_initial_zoom_fit;
  new_globals->do_initial_zoom_fit_used = GLOBALS->do_initial_zoom_fit_used;
  new_globals->do_resize_signals = GLOBALS->do_resize_signals;
@@ -1931,6 +1936,9 @@ void reload_into_new_context_2(void)
  strcpy2_into_new_context(new_globals, &new_globals->pFileChooseFilterName, &GLOBALS->pFileChooseFilterName);
 #endif
 
+ /* search.c */
+ new_globals->regex_which_search_c_1 = GLOBALS->regex_which_search_c_1; /* preserve search type */
+
  /* ttranslate.c */
  strcpy2_into_new_context(new_globals, &new_globals->ttranslate_args, &GLOBALS->ttranslate_args);
 
