@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2016.
+ * Copyright (c) Kermin Elliott Fleming 2007-2017.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -249,11 +249,13 @@ char extload_already_errored; /* from extload.c */
 char **extload_namecache;
 int *extload_namecache_max;
 int *extload_namecache_lens;
+int *extload_namecache_patched;
 struct symbol *extload_sym_block;
 struct Node *extload_node_block;
 void *extload_xc;
 struct symbol *extload_prevsymroot;
 struct symbol *extload_prevsym;
+struct tree **extload_npar;
 int extload_i;
 int extload_hlen;
 unsigned char extload_vt_prev;
@@ -400,6 +402,7 @@ unsigned char *fmem_buf;
 size_t fmem_buf_siz;
 size_t fmem_buf_offs;
 size_t fmem_uncompressed_siz;
+char disable_auto_comphier;
 
 
 /*
@@ -1076,7 +1079,6 @@ GtkCTree *ctree_main; /* from treesearch_gtk2.c 493 */
 struct autocoalesce_free_list *afl_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 494 */
 GtkWidget *window_treesearch_gtk2_c_12; /* from treesearch_gtk2.c 495 */
 GtkWidget *tree_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 496 */
-char bundle_direction_treesearch_gtk2_c_3; /* from treesearch_gtk2.c 497 */
 void (*cleanup_treesearch_gtk2_c_8)(void); /* from treesearch_gtk2.c 498 */
 int pre_import_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 499 */
 Traces tcache_treesearch_gtk2_c_2; /* from treesearch_gtk2.c 500 */
@@ -1084,6 +1086,8 @@ unsigned char dnd_tgt_on_signalarea_treesearch_gtk2_c_1; /* from treesearch_gtk2
 unsigned char dnd_tgt_on_wavearea_treesearch_gtk2_c_1; /* from treesearch_gtk2.c */
 GtkWidget *dnd_sigview; /* from treesearch_gtk2.c */
 GtkPaned *sst_vpaned; /* from treesearch_gtk2.c */
+int fetchlow;
+int fetchhigh;
 
 
 /*
