@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2014 Tony Bybell.
+ * Copyright (c) 2009-2017 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -168,7 +168,11 @@ enum fstHierType {
     FST_HT_ATTRBEGIN   = 3,
     FST_HT_ATTREND     = 4,
 
-    FST_HT_MAX         = 4
+    /* FST_HT_TREEBEGIN and FST_HT_TREEEND are not yet used by FST but are currently used when fstHier bridges other formats */
+    FST_HT_TREEBEGIN   = 5,
+    FST_HT_TREEEND     = 6,
+
+    FST_HT_MAX         = 6
 };
 
 enum fstAttrType {
@@ -191,9 +195,10 @@ enum fstMiscType {
     FST_MT_PATHNAME    = 3,     /* reserved for fstWriterSetSourceStem() string -> number management */
     FST_MT_SOURCESTEM  = 4,     /* use fstWriterSetSourceStem() to emit */
     FST_MT_SOURCEISTEM = 5,     /* use fstWriterSetSourceInstantiationStem() to emit */
-    FST_MT_UNKNOWN     = 6,
+    FST_MT_VALUELIST   = 6,	/* use fstWriterSetValueList() to emit, followed by fstWriterCreateVar*() */
+    FST_MT_UNKNOWN     = 7,
 
-    FST_MT_MAX         = 6
+    FST_MT_MAX         = 7
 };
 
 enum fstArrayType {
@@ -246,7 +251,7 @@ enum fstSupplementalVarType {
     FST_SVT_VHDL_FILE              = 4,
     FST_SVT_VHDL_MEMORY            = 5,
 
-    FST_SVT_MAX                    = 5,
+    FST_SVT_MAX                    = 5
 };
 
 enum fstSupplementalDataType {
@@ -358,6 +363,7 @@ void            fstWriterSetTimescale(void *ctx, int ts);
 void            fstWriterSetTimescaleFromString(void *ctx, const char *s);
 void            fstWriterSetTimezero(void *ctx, int64_t tim);
 void            fstWriterSetUpscope(void *ctx);
+void		fstWriterSetValueList(void *ctx, const char *vl);
 void            fstWriterSetVersion(void *ctx, const char *vers);
 
 
