@@ -30,7 +30,7 @@
 #include "wave_locale.h"
 
 static char *match = NULL;
-static int matchlen = 0;
+static uint32_t matchlen = 0;
 static int names_only = 0;
 static char *killed_list = NULL;
 char killed_value = 1;
@@ -47,7 +47,7 @@ while(*s)
 	char ch = *(s++);
 	if(ch != ' ')
 		{
-		*(d++) = ch;		
+		*(d++) = ch;
 		}
 	}
 *d = 0;
@@ -76,7 +76,7 @@ while((h = fstReaderIterateHier(xc)))
 				{
 				long new_allocated_scopes = allocated_scopes * 2;
 				char **scope_names_2 = calloc(new_allocated_scopes, sizeof(char *));
-			
+
 				memcpy(scope_names_2, scope_names, allocated_scopes * sizeof(char *));
 				free(scope_names);
 
@@ -106,6 +106,8 @@ while((h = fstReaderIterateHier(xc)))
 
 static char *get_facname(void *lt, fstHandle pnt_facidx)
 {
+(void) lt;
+
 if(scope_idx[pnt_facidx] && scope_names[scope_idx[pnt_facidx]])
 	{
 	char *fst_scope_name = scope_names[scope_idx[pnt_facidx]];
@@ -182,7 +184,7 @@ lt=fstReaderOpen(fname);
 if(lt)
 	{
 	int numfacs;
-	
+
 	numfacs = fstReaderGetVarCount(lt) + 1;
 	killed_list = calloc(numfacs, sizeof(char));
 
@@ -218,7 +220,7 @@ return(0);
 
 void print_help(char *nam)
 {
-#ifdef __linux__ 
+#ifdef __linux__
 printf(
 "Usage: %s [OPTION]... [FSTFILE]\n\n"
 "  -d, --dumpfile=FILE        specify FST input dumpfile\n"
@@ -252,7 +254,7 @@ char opt_errors_encountered=0;
 char *lxname=NULL;
 int c;
 int rc;
-int i, j, k;
+uint32_t i, j, k;
 int comprehensive = 0;
 
 
@@ -262,7 +264,7 @@ while (1)
         {
 #ifdef __linux__
         int option_index = 0;
-                        
+
         static struct option long_options[] =
                 {
 		{"dumpfile", 1, 0, 'd'},
@@ -271,16 +273,16 @@ while (1)
 		{"namesonly", 0, 0, 'n'},
 		{"comprehensive", 0, 0, 'c'},
                 {"help", 0, 0, 'h'},
-                {0, 0, 0, 0}  
+                {0, 0, 0, 0}
                 };
-                
+
         c = getopt_long (argc, argv, "d:m:x:nch", long_options, &option_index);
 #else
         c = getopt      (argc, argv, "d:m:x:nch");
 #endif
-                        
+
         if (c == -1) break;     /* no more args */
-                        
+
         switch (c)
                 {
 		case 'c':
@@ -347,29 +349,29 @@ while (1)
                 case 'h':
 			print_help(argv[0]);
                         break;
-                        
+
                 case '?':
                         opt_errors_encountered=1;
                         break;
-                        
+
                 default:
                         /* unreachable */
                         break;
                 }
         }
 
-if(!names_only && comprehensive) 
+if(!names_only && comprehensive)
 	{
 	killed_value = 0;
 	}
-                        
+
 if(opt_errors_encountered)
         {
         print_help(argv[0]);
         }
 
 if (optind < argc)
-        {               
+        {
         while (optind < argc)
                 {
                 if(lxname)
@@ -380,7 +382,7 @@ if (optind < argc)
                 strcpy(lxname, argv[optind++]);
                 }
         }
-                        
+
 if(!lxname)
         {
         print_help(argv[0]);
