@@ -176,7 +176,7 @@ main (int argc, char **argv)
 		case ghw_res_snapshot:
 		case ghw_res_cycle:
 		  if (flag_disp_time)
-		    printf ("Time is "GHWLLD" fs\n", hp->snap_time);
+		    printf ("Time is "GHWPRI64" fs\n", hp->snap_time);
 		  if (flag_disp_signals)
 		    ghw_disp_values (hp);
 		  break;
