@@ -3,19 +3,19 @@
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
- * to deal in the Software without restriction, including without limitation 
- * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
- * and/or sell copies of the Software, and to permit persons to whom the   
- * Software is furnished to do so, subject to the following conditions: 
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
  *
  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,  
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL   
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
  * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING   
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
  */
@@ -83,12 +83,12 @@ typedef unsigned long long granmsk_t;
 #define LXT2_WR_GRAN_1VAL (LXT2_WR_ULLDESC(1))
 #else
 typedef unsigned int granmsk_t;
-#define LXT2_WR_GRAN_0VAL (0)   
+#define LXT2_WR_GRAN_0VAL (0)
 #define LXT2_WR_GRAN_1VAL (1)
 #endif
 
 
-enum LXT2_WR_Encodings { 
+enum LXT2_WR_Encodings {
 	LXT2_WR_ENC_0,
 	LXT2_WR_ENC_1,
 	LXT2_WR_ENC_INV,
@@ -132,12 +132,12 @@ struct lxt2_wr_ds_tree_node {
  */
 typedef struct lxt2_wr_dslxt_tree_node lxt2_wr_dslxt_Tree;
 struct lxt2_wr_dslxt_tree_node {
-    lxt2_wr_dslxt_Tree * left, * right;  
+    lxt2_wr_dslxt_Tree * left, * right;
     char *item;
     unsigned int val;
     lxt2_wr_dslxt_Tree * next;
 };
-                                        
+
 
 struct lxt2_wr_trace
 {
@@ -163,7 +163,7 @@ off_t current_chunk, current_chunkz;
 struct lxt2_wr_symbol *sym[LXT2_WR_SYMPRIME];
 struct lxt2_wr_symbol **sorted_facs;
 struct lxt2_wr_symbol *symchain;
-int numfacs, numalias;
+unsigned int numfacs, numalias;
 int numfacbytes;
 int longestname;
 
@@ -174,7 +174,7 @@ lxttime_t mintime, maxtime;
 lxtstime_t timezero;
 unsigned int timegranule;
 int timescale;
-int timepos;
+unsigned int timepos;
 unsigned int maxgranule;
 lxttime_t firsttime, lasttime;
 lxttime_t timetable[LXT2_WR_GRANULE_SIZE];
