@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2014.
+ * Copyright (c) Tony Bybell 1999-2017.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -314,6 +314,12 @@ WV_MENU_HWV,
 WV_MENU_NUMITEMS
 };
 
+enum WV_RecurseType {
+WV_RECURSE_APPEND,
+WV_RECURSE_INSERT,
+WV_RECURSE_REPLACE,
+};
+
 void menu_new_viewer(gpointer null_data, guint callback_action, GtkWidget *widget);
 void menu_write_vcd_file(gpointer null_data, guint callback_action, GtkWidget *widget);
 void menu_write_lxt_file(gpointer null_data, guint callback_action, GtkWidget *widget);
