@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2010
+ * Copyright (c) Tony Bybell 2010-2017
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,14 +19,14 @@ void select_tree_node(char *name);
 void dnd_setup(GtkWidget *src, GtkWidget *widget, int enable_receive); /* dnd from gtk2 tree to signalwindow */
 void treeview_select_all_callback(void); /* gtk2 */
 void treeview_unselect_all_callback(void); /* gtk2 */
-struct tree *fetchlow(struct tree *t);
-struct tree *fetchhigh(struct tree *t);
-void fetchvex(struct tree *t, char direction);
 int treebox_is_active(void);
 
 #if WAVE_USE_GTK2
 void DND_helper_quartz(char *data);
 #endif
 
+void recurse_import(GtkWidget *widget, guint callback_action);
+#define WV_RECURSE_IMPORT_WARN (0)
+
 #endif
 
