@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tristan Gingold and Tony Bybell 2006-2014.
+ * Copyright (c) Tristan Gingold and Tony Bybell 2006-2017.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -883,173 +883,6 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
 
 /***************************************************************************/
 
-
-
-/* Get the highest signal from T.  */
-struct tree *fetchhigh(struct tree *t)
-{
-while(t->child) t=t->child;
-return(t);
-}
-
-/* Get the lowest signal from T.  */
-struct tree *fetchlow(struct tree *t)
-{
-if(t->child)
-	{
-	t=t->child;
-
-	for(;;)
-		{
-		while(t->next) t=t->next;
-		if(t->child) t=t->child; else break;
-		}
-	}
-return(t);
-}
-
-static void fetchvex2(struct tree *t, char direction, char level)
-{
-while(t)
-	{
-	if(t->child)
-		{
-		if(t->child->child)
-			{
-			fetchvex2(t->child, direction, 1);
-			}
-			else
-			{
-			add_vector_range(NULL, fetchlow(t)->t_which,
-				fetchhigh(t)->t_which, direction);
-			}
-		}
-	if(level) { t=t->next; } else { break; }
-	}
-}
-
-void fetchvex(struct tree *t, char direction)
-{
-if(t)
-	{
-	if(t->child)
-		{
-		fetchvex2(t, direction, 0);
-		}
-		else
-		{
-		add_vector_range(NULL, fetchlow(t)->t_which,
-			fetchhigh(t)->t_which, direction);
-		}
-	}
-}
-
-
-/* call cleanup() on ok/insert functions */
-
-static void
-bundle_cleanup_foreach (GtkTreeModel *model,
-			GtkTreePath *path,
-			GtkTreeIter *iter,
-			gpointer data)
-{
-(void)path;
-(void)data;
-
-  struct tree *sel;
-
-  /* Extract the tree.  */
-  gtk_tree_model_get (model, iter, TREE_COLUMN, &sel, -1);
-
-  if(!sel) return;
-
-if(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3)
-        {
-        char *efix;
-
-	if(!strlen(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3))
-		{
-	        DEBUG(printf("Bundle name is not specified--recursing into hierarchy.\n"));
-		fetchvex(sel, GLOBALS->bundle_direction_treesearch_gtk2_c_3);
-		}
-		else
-		{
-	        efix=GLOBALS->entrybox_text_local_treesearch_gtk2_c_3;
-	        while(*efix)
-	                {
-	                if(*efix==' ')
-	                        {
-	                        *efix='_';
-	                        }
-	                efix++;
-	                }
-
-	        DEBUG(printf("Bundle name is: %s\n",GLOBALS->entrybox_text_local_treesearch_gtk2_c_3));
-	        add_vector_range(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3,
-				fetchlow(sel)->t_which,
-				fetchhigh(sel)->t_which,
-				GLOBALS->bundle_direction_treesearch_gtk2_c_3);
-		}
-        free_2(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3);
-        }
-	else
-	{
-        DEBUG(printf("Bundle name is not specified--recursing into hierarchy.\n"));
-	fetchvex(sel, GLOBALS->bundle_direction_treesearch_gtk2_c_3);
-	}
-}
-
-static void
-bundle_cleanup(GtkWidget *widget, gpointer data)
-{
-(void)widget;
-(void)data;
-
-  gtk_tree_selection_selected_foreach
-    (GLOBALS->sig_selection_treesearch_gtk2_c_1, &bundle_cleanup_foreach, NULL);
-
-MaxSignalLength();
-signalarea_configure_event(GLOBALS->signalarea, NULL);
-wavearea_configure_event(GLOBALS->wavearea, NULL);
-}
-
-static void
-bundle_callback_generic(void)
-{
-  if(!GLOBALS->autoname_bundles)
-    {
-      if (gtk_tree_selection_count_selected_rows (GLOBALS->sig_selection_treesearch_gtk2_c_1) != 1)
-	return;
-      entrybox_local("Enter Bundle Name",300,"",128,
-		     GTK_SIGNAL_FUNC(bundle_cleanup));
-    }
-  else
-    {
-      GLOBALS->entrybox_text_local_treesearch_gtk2_c_3=NULL;
-      bundle_cleanup(NULL, NULL);
-    }
-}
-
-static void
-bundle_callback_up(GtkWidget *widget, gpointer data)
-{
-(void)widget;
-(void)data;
-
-GLOBALS->bundle_direction_treesearch_gtk2_c_3=0;
-bundle_callback_generic();
-}
-
-static void
-bundle_callback_down(GtkWidget *widget, gpointer data)
-{
-(void)widget;
-(void)data;
-
-GLOBALS->bundle_direction_treesearch_gtk2_c_3=1;
-bundle_callback_generic();
-}
-
 /* Callback for insert/replace/append buttions.
    This call-back is called for every signal selected.  */
 enum cb_action { ACTION_INSERT, ACTION_REPLACE, ACTION_APPEND, ACTION_PREPEND };
@@ -1684,37 +1517,6 @@ do_tooltips:
 		"Add selected signal hierarchy after last highlighted signal on the main window.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button2, TRUE, FALSE, 0);
 
-    if(GLOBALS->vcd_explicit_zero_subscripts>=0)
-	{
-    	button3 = gtk_button_new_with_label (" Bundle Up ");
-    	gtk_container_border_width (GTK_CONTAINER (button3), 3);
-    	gtkwave_signal_connect_object (GTK_OBJECT (button3), "clicked",GTK_SIGNAL_FUNC(bundle_callback_up),GTK_OBJECT (GLOBALS->window_treesearch_gtk2_c_12));
-    	gtk_widget_show (button3);
-    	gtk_tooltips_set_tip_2(tooltips, button3,
-		"Bundle selected signal hierarchy into a single bit "
-		"vector with the topmost signal as the LSB and the "
-		"lowest as the MSB.  Entering a zero length bundle "
-		"name will reconstruct the individual vectors "
-		"in the hierarchy.  Otherwise, all the bits in "
-		"the hierarchy will be coalesced with the supplied "
-		"name into a single vector.",NULL);
-    	gtk_box_pack_start (GTK_BOX (hbox), button3, TRUE, FALSE, 0);
-
-    	button3a = gtk_button_new_with_label (" Bundle Down ");
-    	gtk_container_border_width (GTK_CONTAINER (button3a), 3);
-    	gtkwave_signal_connect_object (GTK_OBJECT (button3a), "clicked",GTK_SIGNAL_FUNC(bundle_callback_down),GTK_OBJECT (GLOBALS->window_treesearch_gtk2_c_12));
-    	gtk_widget_show (button3a);
-    	gtk_tooltips_set_tip_2(tooltips, button3a,
-		"Bundle selected signal hierarchy into a single bit "
-		"vector with the topmost signal as the MSB and the "
-		"lowest as the LSB.  Entering a zero length bundle "
-		"name will reconstruct the individual vectors "
-		"in the hierarchy.  Otherwise, all the bits in "
-		"the hierarchy will be coalesced with the supplied "
-		"name into a single vector.",NULL);
-   	gtk_box_pack_start (GTK_BOX (hbox), button3a, TRUE, FALSE, 0);
-	}
-
     button4 = gtk_button_new_with_label (" Replace ");
     gtk_container_border_width (GTK_CONTAINER (button4), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button4), "clicked",GTK_SIGNAL_FUNC(replace_callback),GTK_OBJECT (GLOBALS->window_treesearch_gtk2_c_12));
@@ -1964,37 +1766,6 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 		"Add selected signal hierarchy after last highlighted signal on the main window.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button2, TRUE, FALSE, 0);
 
-    if(GLOBALS->vcd_explicit_zero_subscripts>=0)
-	{
-    	button3 = gtk_button_new_with_label (" Bundle Up ");
-    	gtk_container_border_width (GTK_CONTAINER (button3), 3);
-    	gtkwave_signal_connect_object (GTK_OBJECT (button3), "clicked", GTK_SIGNAL_FUNC(bundle_callback_up), GTK_OBJECT (GLOBALS->gtk2_tree_frame));
-    	gtk_widget_show (button3);
-    	gtk_tooltips_set_tip_2(tooltips, button3,
-		"Bundle selected signal hierarchy into a single bit "
-		"vector with the topmost signal as the LSB and the "
-		"lowest as the MSB.  Entering a zero length bundle "
-		"name will reconstruct the individual vectors "
-		"in the hierarchy.  Otherwise, all the bits in "
-		"the hierarchy will be coalesced with the supplied "
-		"name into a single vector.",NULL);
-    	gtk_box_pack_start (GTK_BOX (hbox), button3, TRUE, FALSE, 0);
-
-    	button3a = gtk_button_new_with_label (" Bundle Down ");
-    	gtk_container_border_width (GTK_CONTAINER (button3a), 3);
-    	gtkwave_signal_connect_object (GTK_OBJECT (button3a), "clicked", GTK_SIGNAL_FUNC(bundle_callback_down), GTK_OBJECT (GLOBALS->gtk2_tree_frame));
-    	gtk_widget_show (button3a);
-    	gtk_tooltips_set_tip_2(tooltips, button3a,
-		"Bundle selected signal hierarchy into a single bit "
-		"vector with the topmost signal as the MSB and the "
-		"lowest as the LSB.  Entering a zero length bundle "
-		"name will reconstruct the individual vectors "
-		"in the hierarchy.  Otherwise, all the bits in "
-		"the hierarchy will be coalesced with the supplied "
-		"name into a single vector.",NULL);
-   	gtk_box_pack_start (GTK_BOX (hbox), button3a, TRUE, FALSE, 0);
-	}
-
     button4 = gtk_button_new_with_label (" Replace ");
     gtk_container_border_width (GTK_CONTAINER (button4), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button4), "clicked", GTK_SIGNAL_FUNC(replace_callback), GTK_OBJECT (GLOBALS->gtk2_tree_frame));
@@ -2549,3 +2320,419 @@ void dnd_setup(GtkWidget *src, GtkWidget *w, int enable_receive)
 	}
 }
 
+/***************************************************************************/
+
+static void recurse_append_callback(GtkWidget *widget, gpointer data)
+{
+int i;
+
+if(!GLOBALS->sst_sig_root_treesearch_gtk2_c_1 || !data) return;
+
+set_window_busy(widget);
+
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
+        {
+        struct symbol *s;
+	if(i<0) break; /* GHW */
+        s=GLOBALS->facs[i];
+	if(s->vec_root)
+		{
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
+		}
+        }
+
+/* LX2 */
+if(GLOBALS->is_lx2)
+	{
+	int pre_import = 0;
+
+	for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
+	        {
+	        struct symbol *s, *t;
+		if(i<0) break; /* GHW */
+	        s=GLOBALS->facs[i];
+		t=s->vec_root;
+		if((t)&&(GLOBALS->autocoalesce))
+			{
+			if(get_s_selected(t))
+				{
+				while(t)
+					{
+					if(t->n->mv.mvlfac)
+						{
+						lx2_set_fac_process_mask(t->n);
+						pre_import++;
+						}
+					t=t->vec_chain;
+					}
+				}
+			}
+			else
+			{
+			if(s->n->mv.mvlfac)
+				{
+				lx2_set_fac_process_mask(s->n);
+				pre_import++;
+				}
+			}
+	        }
+
+	if(pre_import)
+		{
+		lx2_import_masked();
+		}
+	}
+/* LX2 */
+
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
+        {
+	int len;
+        struct symbol *s, *t;
+	if(i<0) break; /* GHW */
+        s=GLOBALS->facs[i];
+	t=s->vec_root;
+	if((t)&&(GLOBALS->autocoalesce))
+		{
+		if(get_s_selected(t))
+			{
+			set_s_selected(t, 0);
+			len=0;
+			while(t)
+				{
+				len++;
+				t=t->vec_chain;
+				}
+			if(len) add_vector_chain(s->vec_root, len);
+			}
+		}
+		else
+		{
+	        AddNodeUnroll(s->n, NULL);
+		}
+        }
+
+set_window_idle(widget);
+
+GLOBALS->traces.scroll_top = GLOBALS->traces.scroll_bottom = GLOBALS->traces.last;
+MaxSignalLength();
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
+}
+
+
+static void recurse_insert_callback(GtkWidget *widget, gpointer data)
+{
+Traces tcache;
+int i;
+
+if(!GLOBALS->sst_sig_root_treesearch_gtk2_c_1 || !data) return;
+
+memcpy(&tcache,&GLOBALS->traces,sizeof(Traces));
+GLOBALS->traces.total=0;
+GLOBALS->traces.first=GLOBALS->traces.last=NULL;
+
+set_window_busy(widget);
+
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
+        {
+        struct symbol *s;
+	if(i<0) break; /* GHW */
+        s=GLOBALS->facs[i];
+	if(s->vec_root)
+		{
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
+		}
+        }
+
+/* LX2 */
+if(GLOBALS->is_lx2)
+	{
+	int pre_import = 0;
+
+	for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
+	        {
+	        struct symbol *s, *t;
+		if(i<0) break; /* GHW */
+	        s=GLOBALS->facs[i];
+		t=s->vec_root;
+		if((t)&&(GLOBALS->autocoalesce))
+			{
+			if(get_s_selected(t))
+				{
+				while(t)
+					{
+					if(t->n->mv.mvlfac)
+						{
+						lx2_set_fac_process_mask(t->n);
+						pre_import++;
+						}
+					t=t->vec_chain;
+					}
+				}
+			}
+			else
+			{
+			if(s->n->mv.mvlfac)
+				{
+				lx2_set_fac_process_mask(s->n);
+				pre_import++;
+				}
+			}
+	        }
+
+	if(pre_import)
+		{
+		lx2_import_masked();
+		}
+	}
+/* LX2 */
+
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
+        {
+	int len;
+        struct symbol *s, *t;
+	if(i<0) break; /* GHW */
+        s=GLOBALS->facs[i];
+	t=s->vec_root;
+	if((t)&&(GLOBALS->autocoalesce))
+		{
+		if(get_s_selected(t))
+			{
+			set_s_selected(t, 0);
+			len=0;
+			while(t)
+				{
+				len++;
+				t=t->vec_chain;
+				}
+			if(len) add_vector_chain(s->vec_root, len);
+			}
+		}
+		else
+		{
+	        AddNodeUnroll(s->n, NULL);
+		}
+        }
+
+set_window_idle(widget);
+
+GLOBALS->traces.buffercount=GLOBALS->traces.total;
+GLOBALS->traces.buffer=GLOBALS->traces.first;
+GLOBALS->traces.bufferlast=GLOBALS->traces.last;
+GLOBALS->traces.first=tcache.first;
+GLOBALS->traces.last=tcache.last;
+GLOBALS->traces.total=tcache.total;
+
+PasteBuffer();
+
+GLOBALS->traces.buffercount=tcache.buffercount;
+GLOBALS->traces.buffer=tcache.buffer;
+GLOBALS->traces.bufferlast=tcache.bufferlast;
+
+MaxSignalLength();
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
+}
+
+
+static void recurse_replace_callback(GtkWidget *widget, gpointer data)
+{
+Traces tcache;
+int i;
+Trptr tfirst=NULL, tlast=NULL;
+
+if(!GLOBALS->sst_sig_root_treesearch_gtk2_c_1 || !data) return;
+
+memcpy(&tcache,&GLOBALS->traces,sizeof(Traces));
+GLOBALS->traces.total=0;
+GLOBALS->traces.first=GLOBALS->traces.last=NULL;
+
+set_window_busy(widget);
+
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
+        {
+        struct symbol *s;
+	if(i<0) break; /* GHW */
+        s=GLOBALS->facs[i];
+	if(s->vec_root)
+		{
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
+		}
+        }
+
+/* LX2 */
+if(GLOBALS->is_lx2)
+	{
+	int pre_import = 0;
+
+	for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
+	        {
+	        struct symbol *s, *t;
+		if(i<0) break; /* GHW */
+	        s=GLOBALS->facs[i];
+		t=s->vec_root;
+		if((t)&&(GLOBALS->autocoalesce))
+			{
+			if(get_s_selected(t))
+				{
+				while(t)
+					{
+					if(t->n->mv.mvlfac)
+						{
+						lx2_set_fac_process_mask(t->n);
+						pre_import++;
+						}
+					t=t->vec_chain;
+					}
+				}
+			}
+			else
+			{
+			if(s->n->mv.mvlfac)
+				{
+				lx2_set_fac_process_mask(s->n);
+				pre_import++;
+				}
+			}
+	        }
+
+	if(pre_import)
+		{
+		lx2_import_masked();
+		}
+	}
+/* LX2 */
+
+for(i=GLOBALS->fetchlow;i<=GLOBALS->fetchhigh;i++)
+        {
+	int len;
+        struct symbol *s, *t;
+	if(i<0) break; /* GHW */
+        s=GLOBALS->facs[i];
+	t=s->vec_root;
+	if((t)&&(GLOBALS->autocoalesce))
+		{
+		if(get_s_selected(t))
+			{
+			set_s_selected(t, 0);
+			len=0;
+			while(t)
+				{
+				len++;
+				t=t->vec_chain;
+				}
+			if(len) add_vector_chain(s->vec_root, len);
+			}
+		}
+		else
+		{
+	        AddNodeUnroll(s->n, NULL);
+		}
+        }
+
+set_window_idle(widget);
+
+tfirst=GLOBALS->traces.first; tlast=GLOBALS->traces.last;       /* cache for highlighting */
+
+GLOBALS->traces.buffercount=GLOBALS->traces.total;
+GLOBALS->traces.buffer=GLOBALS->traces.first;
+GLOBALS->traces.bufferlast=GLOBALS->traces.last;
+GLOBALS->traces.first=tcache.first;
+GLOBALS->traces.last=tcache.last;
+GLOBALS->traces.total=tcache.total;
+
+{
+Trptr t = GLOBALS->traces.first;
+Trptr *tp = NULL;
+int numhigh = 0;
+int it;
+
+while(t) { if(t->flags & TR_HIGHLIGHT) { numhigh++; } t = t->t_next; }
+if(numhigh)
+        {
+        tp = calloc_2(numhigh, sizeof(Trptr));
+        t = GLOBALS->traces.first;
+        it = 0;
+        while(t) { if(t->flags & TR_HIGHLIGHT) { tp[it++] = t; } t = t->t_next; }
+        }
+
+PasteBuffer();
+
+GLOBALS->traces.buffercount=tcache.buffercount;
+GLOBALS->traces.buffer=tcache.buffer;
+GLOBALS->traces.bufferlast=tcache.bufferlast;
+
+for(i=0;i<numhigh;i++)
+        {
+        tp[i]->flags |= TR_HIGHLIGHT;
+        }
+
+t = tfirst;
+while(t)
+        {
+        t->flags &= ~TR_HIGHLIGHT;
+        if(t==tlast) break;
+        t=t->t_next;
+        }
+
+CutBuffer();
+
+while(tfirst)
+        {
+        tfirst->flags |= TR_HIGHLIGHT;
+        if(tfirst==tlast) break;
+        tfirst=tfirst->t_next;
+        }
+
+if(tp)
+        {
+        free_2(tp);
+        }
+}
+
+MaxSignalLength();
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
+}
+
+
+void recurse_import(GtkWidget *widget, guint callback_action)
+{
+if(GLOBALS->sst_sig_root_treesearch_gtk2_c_1)
+	{
+	int fz;
+
+	GLOBALS->fetchlow = GLOBALS->fetchhigh = -1;
+	if(GLOBALS->sst_sig_root_treesearch_gtk2_c_1->child) recurse_fetch_high_low(GLOBALS->sst_sig_root_treesearch_gtk2_c_1->child);
+	fz = GLOBALS->fetchhigh - GLOBALS->fetchlow + 1;
+	void (*func)(GtkWidget *, gpointer);
+
+	switch(callback_action)
+		{
+		case WV_RECURSE_INSERT:		func = recurse_insert_callback; break;
+		case WV_RECURSE_REPLACE:	func = recurse_replace_callback; break;
+	
+		case WV_RECURSE_APPEND:
+		default:			func = recurse_append_callback; break;
+		}
+
+	if((GLOBALS->fetchlow >= 0) && (GLOBALS->fetchhigh >= 0))
+		{
+		widget = GLOBALS->mainwindow; /* otherwise using widget passed from the menu item crashes on OSX */
+
+		if(fz > WV_RECURSE_IMPORT_WARN)
+			{
+			char recwarn[128];
+			sprintf(recwarn, "Really import %d facilit%s?", fz, (fz==1)?"y":"ies");
+		
+			simplereqbox("Recurse Warning",300,recwarn,"Yes", "No", GTK_SIGNAL_FUNC(func), 0);
+			}
+			else
+			{
+			func(widget, (gpointer)1);
+			}
+		}
+	}
+}
+
+/***************************************************************************/
